crikit.io package — CRIKit2 0.4.3 documentation

# crikit.io package

## Subpackages

- crikit.io.lazy5 package
  - Subpackages
    - crikit.io.lazy5.tests package
      - Submodules
      - crikit.io.lazy5.tests.test_alter module
      - crikit.io.lazy5.tests.test_create module
      - crikit.io.lazy5.tests.test_inspect module
      - crikit.io.lazy5.tests.test_nonh5utils module
      - crikit.io.lazy5.tests.test_ui module
      - crikit.io.lazy5.tests.test_utils module
      - Module contents
    - crikit.io.lazy5.ui package
      - Submodules
      - crikit.io.lazy5.ui.QtHdfLoad module
      - crikit.io.lazy5.ui.qt_HdfLoad module
      - Module contents
  - Submodules
  - crikit.io.lazy5.alter module
  - crikit.io.lazy5.config module
  - crikit.io.lazy5.create module
  - crikit.io.lazy5.inspect module
  - crikit.io.lazy5.nonh5utils module
  - crikit.io.lazy5.utils module
  - Module contents
- crikit.io.tests package
  - Submodules
  - crikit.io.tests.test_hdf5 module
  - Module contents

## Submodules

## crikit.io.csv_nist module

Created on Wed Sep 7 12:36:36 2016

@author: chc

crikit.io.csv_nist.csv_nist_import_data(pth, filename_header, filename_data, output_cls_instance=None)

  Import dataset(s) from HDF file

  Parameters

    - pth (str) – Path

    - filename_header (str) – File name of header

    - filename_data (str) – File name of data

    - output_cls_instance (crikit.data.spectra.Spectrum (or subclass)) – Spectrum class (or sub) object

  Returns

    - Success (bool) – Success of import

    - Data, Meta (list (ndarray, dict)) – If output_cls_instance is None and import is successful, will return the data from dset_list and associated meta data.

## crikit.io.hdf5 module

Created on Mon May 23 10:17:16 2016

@author: chc

crikit.io.hdf5.hdf_import_data(pth, filename, dset_list, output_cls_instance=None)

  Import dataset(s) from HDF file

  Parameters

    - pth (str) – Path

    - filename (str) – File name

    - dset_list (list) – List of 1 or more datasets

    - output_cls_instance (crikit.data.spectra.Spectrum (or subclass)) – Spectrum class (or sub) object

  Returns

    - Success (bool) – Success of import

    - Data, Meta (list (ndarray, dict)) – If output_cls_instance is None and import is successful, will return the data from dset_list and associated meta data.

crikit.io.hdf5.hdf_import_data_macroraster(pth, filename, dset_list, output_cls_instance, config_dict=None)

  Import dataset(s) from HDF file with each dset being a single line scan.

  Parameters

    - pth (str) – Path

    - filename (str) – File name

    - dset_list (list) – List of 1 or more datasets

    - output_cls_instance (crikit.data.spectra.Spectrum (or subclass)) – Spectrum class (or sub) object

  Returns

    - Success (bool) – Success of import

    - Data, Meta (list (ndarray, dict)) – If output_cls_instance is None and import is successful, will return the data from dset_list and associated meta data.

## crikit.io.macros module

Created on Thu May 26 13:16:12 2016

@author: chc

crikit.io.macros.import_csv_nist_special1(pth, filename_header, filename_data, output_cls_instance)

  Import data from CSV File as specified by NIST-specific settings

  Returns

    Success – Whether import was successful

  Return type

    bool

crikit.io.macros.import_hdf_nist_special(pth, filename, dset, output_cls_instance)

  Import data from HDF File as specified by NIST-specific settings

  Returns

    Success – Whether import was successful

  Return type

    bool

## crikit.io.meta_configs module

Configuration settings for HDF imports

Use ‘!’ as the first entry in a list to denote to use the value rather than querying for it

Created on Mon May 23 10:35:19 2016

@author: chc

crikit.io.meta_configs.special_nist_bcars1_sample_scan()

  Return import attributes particular to the “BCARS 1” system at NIST

crikit.io.meta_configs.special_nist_bcars2()

  Return import attributes particular to the “BCARS 2” system at NIST

## crikit.io.meta_process module

Created on Mon May 23 16:55:09 2016

@author: chc

crikit.io.meta_process.meta_process(rosetta, output_cls_instance)

  Uses a conversion dict (rosetta) to process the meta data in output_cls_instance

crikit.io.meta_process.rosetta_query(key, rosetta, output_cls_instance)

  Return the highest-priority value

## Module contents